@@ -1,12 +1,9 @@
 from __future__ import unicode_literals
 
-from . import models
+__version__ = '1.4.0'
 
 
-registered_models = models.registered_models
-
-
-def register(model, app=None, manager_name='history'):
+def register(model, app=None, manager_name='history', **records_config):
     """
     Create historical model for `model` and attach history manager to `model`.
 
@@ -17,9 +14,11 @@ def register(model, app=None, manager_name='history'):
     This method should be used as an alternative to attaching an
     `HistoricalManager` instance directly to `model`.
     """
-    if not model._meta.db_table in registered_models:
-        records = models.HistoricalRecords()
+    from . import models
+    if not model._meta.db_table in models.registered_models:
+        records = models.HistoricalRecords(**records_config)
         records.manager_name = manager_name
         records.module = app and ("%s.models" % app) or model.__module__
+        records.add_extra_methods(model)
         records.finalize(model)
-        registered_models[model._meta.db_table] = model
+        models.registered_models[model._meta.db_table] = model
